@@ -1,5 +1,4 @@
 import platform
-from collections import namedtuple
 from http import HTTPStatus
 
 import click
@@ -7,8 +6,6 @@ import click
 from cnctcli import get_version
 from cnct import ClientError
 
-ContentRange = namedtuple('ContentRange', ('first', 'last', 'count'))
-
 
 def get_user_agent():
     version = get_version()
@@ -38,12 +35,3 @@ def handle_http_error(res: ClientError):
         raise click.ClickException(f'{status}: {code} - {message}')
 
     raise click.ClickException(f'{status}: unexpected error.')
-
-
-def parse_content_range(value):
-    if not value:
-        return
-    _, info = value.split()
-    first_last, count = info.split('/')
-    first, last = first_last.split('-')
-    return ContentRange(int(first), int(last), int(count))
